@@ -96,7 +96,7 @@ impl Client {
         S::Error: Into<BoxError>,
         B: http_body::Body<Data = bytes::Bytes> + Send + 'static,
         B::Error: std::error::Error + Send + Sync + 'static,
-        T: Into<String>
+        T: Into<String>,
     {
         // Transform response body to `hyper::Body` and use type erased error to avoid type parameters.
         let service = MapResponseBodyLayer::new(|b: B| Body::wrap_stream(b.into_stream()))
@@ -606,7 +606,7 @@ mod tests {
 
         let pods: Api<Pod> = Api::default_namespaced(Client::new(mock_service, "default"));
         let pod = pods.get("test").await.unwrap();
-        assert_eq!(pod.metadata.annotations.get("kube-rs").unwrap(), "test");
+        assert_eq!(pod.metadata.annotations.unwrap().get("kube-rs").unwrap(), "test");
         spawned.await.unwrap();
     }
 }
